HiFive's API
============
Contents:

.. toctree::
   :maxdepth: 1

   fragment.rst
   fend.rst
   fivec_data.rst
   hic_data.rst
   fivec.rst
   hic.rst
   fivec_binning.rst
   hic_binning.rst
   plotting.rst

